@@ -1,4 +1,5 @@
-package Devel::Examine::Subs;
+package Devel::Examine::Subs 1.39;
+use 5.012;
 use warnings;
 use strict;
 
@@ -8,12 +9,10 @@ use Data::Dumper;
 use Devel::Examine::Subs::Engine;
 use Devel::Examine::Subs::Preprocessor;
 use Devel::Examine::Subs::Prefilter;
+use File::Copy;
 use File::Find;
 use PPI;
 use Symbol;
-use Tie::File;
-
-our $VERSION = '1.37';
 
 BEGIN {
 
@@ -54,6 +53,7 @@ sub new {
     return $self;
 }
 sub run {
+
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -69,8 +69,8 @@ sub run {
         $struct = $self->_run_directory;
     }
     else {
-        $self->_end_of_line($self->{params}{file}) if $self->{params}{file};
-        $struct = $self->_core($p);
+        $struct = $self->_core;
+        $self->_write_file if $self->{write_file_contents};
     }
 
     $self->_run_end(1);
@@ -79,6 +79,7 @@ sub run {
     return $struct;
 }
 sub _run_directory {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -89,7 +90,9 @@ sub _run_directory {
     my $dir = $self->{params}{file};
 
     find({wanted => sub {
+            
             trace() if $ENV{TRACE};
+
             return if ! -f;
 
             my @extensions = @{$self->{params}{extensions}};
@@ -111,11 +114,11 @@ sub _run_directory {
 
     for my $file (@files){
         
-        $self->_end_of_line($file);
-
         $self->{params}{file} = $file;
         my $data = $self->_core($p);
 
+        $self->_write_file if $self->{write_file_contents};
+
         my $exists = 0;
         $exists = %$data if ref($data) eq 'HASH';
         $exists = @$data if ref($data) eq 'ARRAY';
@@ -125,25 +128,8 @@ sub _run_directory {
 
     return \%struct;
 }
-sub _end_of_line {
-    trace() if $ENV{TRACE};
-
-    my $self = shift;
-    my $file = shift;
-
-    $ENV{DES_EOL} = "\n";
-
-    return if $^O ne 'MSWin32';
-
-    tie my @tie_file, 'Tie::File', $file, recsep => $ENV{DES_EOL} or die $!;
-
-    if (@tie_file && $tie_file[0] =~ /\r\n/){
-        $ENV{DES_EOL} = "\r\n";
-    }
-
-    untie @tie_file;
-}
 sub _run_end {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -154,6 +140,7 @@ sub _run_end {
     return $self->{run_end};
 }
 sub _cache {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -177,12 +164,14 @@ sub _cache {
     }
 }
 sub _cache_enabled {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
     return $self->{params}{cache};
 }
 sub _cache_safe {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -193,6 +182,7 @@ sub _cache_safe {
     return $self->{cache_safe};
 }
 sub _params {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -200,6 +190,7 @@ sub _params {
     return \%params;
 }
 sub _config {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -247,6 +238,7 @@ sub _config {
         inject_use => 0,
         inject_after_sub_def => 0,
         delete => 0,
+        file_contents => 0,
     );
 
     $self->{valid_params} = \%valid_params;
@@ -295,12 +287,18 @@ sub _config {
     }
 }
 sub _clean_config {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
     my $config_vars = shift; # href of valid params
     my $p = shift; # href of params passed in
 
+    # params that get set after the call to _config() need
+    # to be deleted manually here
+
+#    delete $p->{file_contents};
+
     for my $var (keys %$config_vars){
        
         last if ! $self->_run_end;
@@ -322,13 +320,18 @@ sub _clean_config {
     }
 }
 sub _clean_core_config {
+    
     trace() if $ENV{TRACE};
 
-    # deletes core phase info after each run
-
     my $self = shift;
 
-    my @core_phases = qw( 
+    # deletes core phase info after each run
+
+    # clean params that we collected after _clean_config()
+
+    delete $self->{params}{file_contents};
+
+    my @core_phases = qw(
         pre_proc
         pre_filter
         engine
@@ -339,9 +342,9 @@ sub _clean_core_config {
     }
 }
 sub _file {
+    
     trace() if $ENV{TRACE};
 
-
     my $self = shift;
     my $p = shift;
 
@@ -396,7 +399,66 @@ sub _file {
 
    return $self->{params}{file};
 }
+sub _read_file {
+    
+    trace() if $ENV{TRACE};
+
+    my $self = shift;
+    my $p = shift;
+
+    my $file = $p->{file};
+    my $copy = $self->{params}{copy};
+
+    return if ! $file;
+
+    copy $file, "$file.bak" or croak $!;
+
+    open my $fh, '<', $file
+      or croak "Can't open the file $file: $!";
+
+    my @file_contents = <$fh>;
+
+    close $fh or croak $!;
+
+    $self->{file_eol} = "\n";
+
+    if ($file_contents[0] && $file_contents[0] =~ /(\R)/){
+        $self->{file_eol} = $1;
+    }
+
+    for (@file_contents){
+        s/\R//g;
+    }
+
+    @{ $p->{file_contents} } = @file_contents;
+    @{ $self->{file_contents} } = @file_contents;
+
+    return @file_contents;
+}
+sub _write_file {
+
+    trace() if $ENV{TRACE};
+
+    my $self = shift;
+
+    my $file = $self->{params}{file};
+    my $copy = $self->{params}{copy};
+    my $contents = $self->{write_file_contents};
+
+    return if ! $file;
+
+    $file = $copy if $copy;
+
+    open my $wfh, '>', $file or croak $!;
+
+    for (@$contents){
+        print $wfh "$_$self->{file_eol}";
+    }
+
+    close $wfh or croak !$;
+}
 sub _core {
+
     trace() if $ENV{TRACE};
     
     my $self = shift;
@@ -406,6 +468,8 @@ sub _core {
     my $search = $self->{params}{search};
     my $file = $self->{params}{file};
 
+    $self->_read_file($p);
+
     # pre processor
 
     my $data;
@@ -415,7 +479,14 @@ sub _core {
 
         $data = $pre_proc->($p);
 
-        # for things that don't need to process files 
+        if ($self->{params}{pre_proc_dump}){
+            print Dumper $data;
+            exit;
+        }
+
+        $self->{write_file_contents} = $p->{write_file_contents};
+
+        # for things that don't need to process files
         # (such as 'module'), return early
 
         if ($self->{params}{pre_proc_return}){
@@ -456,6 +527,7 @@ sub _core {
     if ($self->{params}{pre_filter}){
         for my $pre_filter ($self->_pre_filter){
             $subs = $pre_filter->($p, $subs);
+            $self->{write_file_contents} = $p->{write_file_contents};
             $self->{data} = $subs;
         }
     }  
@@ -470,6 +542,7 @@ sub _core {
 
     if ($self->{params}{engine}){
         $subs = $engine->($p, $subs);
+        $self->{write_file_contents} = $p->{write_file_contents};
     }
 
     # core dump
@@ -487,10 +560,11 @@ sub _core {
     }
 
     $self->{data} = $subs;
-    
+
     return $subs;
 }
 sub _subs {
+    
     trace() if $ENV{TRACE};
     
     my $self = shift;
@@ -504,13 +578,12 @@ sub _subs {
 
     return if ! $PPIsubs;
 
-    tie my @TIE_file, 'Tie::File', $file, recsep => $ENV{DES_EOL}
-      or die $!;
+    my @file_contents = @{ $self->{params}{file_contents} };
 
     my %subs;
     $subs{$file} = {};
     
-    @{$subs{$file}{TIE_file}} = @TIE_file;
+    @{$subs{$file}{contents}} = @file_contents;
 
     for my $PPI_sub (@{$PPIsubs}){
 
@@ -550,20 +623,19 @@ sub _subs {
         # pull out just the subroutine from the file 
         # array and attach it to the structure
 
-        my @sub_definition = @TIE_file[
+        my @sub_definition = @file_contents[
                                     $subs{$file}{subs}{$name}{start}
                                     ..
                                     $subs{$file}{subs}{$name}{end}
                                    ];
 
-          $subs{$file}{subs}{$name}{TIE_file_sub} = \@sub_definition;
+          $subs{$file}{subs}{$name}{contents} = \@sub_definition;
     }
    
-    untie @TIE_file;
-
     return \%subs;
 }
 sub _pre_proc {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -612,15 +684,10 @@ sub _pre_proc {
         $cref = $pre_proc;
     }
     
-    if ($self->{params}{pre_proc_dump}){
-        my $data = $cref->($p);
-        print Dumper $data;
-        exit;
-    }
-
     return $cref;
 }
 sub _pre_filter {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -698,6 +765,7 @@ sub _pre_filter {
     return @pre_filters;
 }
 sub _engine {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -753,6 +821,7 @@ sub _engine {
     return $cref;
 }
 sub pre_procs {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -767,6 +836,7 @@ sub pre_procs {
     return @pre_procs;
 }
 sub pre_filters {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -781,6 +851,7 @@ sub pre_filters {
     return @pre_filters;
 }
 sub engines {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -795,6 +866,7 @@ sub engines {
     return @engines;
 }
 sub has {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -806,6 +878,7 @@ sub has {
     $self->run($p);
 }
 sub missing {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -816,6 +889,7 @@ sub missing {
     $self->run($p);
 }
 sub all {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -826,6 +900,7 @@ sub all {
     $self->run($p);
 }
 sub lines {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -840,6 +915,7 @@ sub lines {
     $self->run($p);
 }
 sub module {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -856,6 +932,7 @@ sub module {
     $self->run($p);
 }
 sub objects {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -867,6 +944,7 @@ sub objects {
     $self->run($p);
 }
 sub search_replace {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -880,6 +958,7 @@ sub search_replace {
     $self->run($p);
 }
 sub inject {
+    
     trace() if $ENV{TRACE};
     my $self = shift;
     my $p = $self->_params(@_);
@@ -894,6 +973,7 @@ sub inject {
     $self->run($p);
 }
 sub remove {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -905,6 +985,7 @@ sub remove {
     $self->run($p);
 }
 sub inject_after {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -922,6 +1003,7 @@ sub inject_after {
     $self->run($p);
 }
 sub add_functionality {
+   
     trace() if $ENV{TRACE};
     
     my $self = shift;
@@ -979,15 +1061,10 @@ sub add_functionality {
                                     pre_filter => 'end_of_last_sub',
                                 });
 
-    
-    tie my @TIE_file, 'Tie::File', $file, recsep => $ENV{DES_EOL} 
-      or croak "can't Tie::File the file $file: $!";
-
-    my $end_line = $des->run;
-
-    push @TIE_file, @code;
+    $p->{write_file_contents} = \@code;
 }
 sub valid_params {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
