@@ -1,4 +1,5 @@
-package Devel::Examine::Subs::Engine;
+package Devel::Examine::Subs::Engine 1.39;
+use 5.012;
 use strict;
 use warnings;
 
@@ -7,9 +8,6 @@ use Data::Dumper;
 use Devel::Examine::Subs;
 use Devel::Examine::Subs::Sub;
 use File::Copy;
-use Tie::File;
-
-our $VERSION = '1.37';
 
 BEGIN {
 
@@ -28,6 +26,7 @@ BEGIN {
 };
 
 sub new {
+    
     trace() if $ENV{TRACE};
 
     my $self = {};
@@ -38,6 +37,7 @@ sub new {
     return $self;
 }
 sub _dt {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -60,6 +60,7 @@ sub _dt {
     return $dt;
 }
 sub exists {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -73,6 +74,7 @@ sub exists {
     }
 }
 sub _test {
+    
     trace() if $ENV{TRACE};
 
     return sub {
@@ -81,17 +83,21 @@ sub _test {
     };
 }
 sub _test_print {
+    
     trace() if $ENV{TRACE};
 
     return sub {
+        
         trace() if $ENV{TRACE};
         print "Hello, world!\n";
     };
 }
 sub all {
+    
     trace() if $ENV{TRACE};
 
     return sub {
+        
         trace() if $ENV{TRACE};
 
         my $p = shift;
@@ -105,9 +111,11 @@ sub all {
     };
 }
 sub has {
+    
     trace() if $ENV{TRACE};
 
     return sub {
+        
         trace() if $ENV{TRACE};
         
         my $p = shift;
@@ -123,9 +131,11 @@ sub has {
     };
 }
 sub missing {
+    
     trace() if $ENV{TRACE};
 
     return sub {
+        
         trace() if $ENV{TRACE};
 
         my $p = shift;
@@ -144,7 +154,7 @@ sub missing {
 
         for my $file (keys %$struct){
             for my $sub (keys %{$struct->{$file}{subs}}){
-                my @code = @{$struct->{$file}{subs}{$sub}{TIE_file_sub}};
+                my @code = @{$struct->{$file}{subs}{$sub}{contents}};
 
                 my @clean;
 
@@ -161,9 +171,11 @@ sub missing {
     };
 }
 sub lines {
+    
     trace() if $ENV{TRACE};
 
     return sub {
+        
         trace() if $ENV{TRACE};
         
         my $p = shift;
@@ -174,7 +186,7 @@ sub lines {
         for my $file (keys %$struct){
             for my $sub (keys %{$struct->{$file}{subs}}){
                 my $line_num = $struct->{$file}{subs}{$sub}{start};
-                my @code = @{$struct->{$file}{subs}{$sub}{TIE_file_sub}};
+                my @code = @{$struct->{$file}{subs}{$sub}{contents}};
                 for my $line (@code){
                     $line_num++;
                     push @{$return{$sub}}, {$line_num => $line};
@@ -185,11 +197,13 @@ sub lines {
     };
 }
 sub objects {
+    
     trace() if $ENV{TRACE};
 
     # uses 'subs' pre_filter
 
     return sub {
+        
         trace() if $ENV{TRACE};
 
         my $p = shift;
@@ -245,16 +259,18 @@ sub objects {
     };
 }
 sub search_replace {
+
     trace() if $ENV{TRACE};
 
     return sub {
+
         trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
-        my $des = shift;
 
         my $file = $p->{file};
+        my @file_contents = @{ $p->{file_contents} } if $p->{file_contents};
         my $search = $p->{search};
         
         if ($search && ! $p->{regex}){
@@ -262,7 +278,6 @@ sub search_replace {
         }
 
         my $replace = $p->{replace};
-        my $copy = $p->{copy} if $p->{copy};
 
         if (! $file){
             croak "\nDevel::Examine::Subs::Engine::search_replace " .
@@ -285,29 +300,107 @@ sub search_replace {
         }
         
  
-        copy $file, "$file.bak";
-
-        if ($copy && -f $copy){
-            unlink $copy;
-        }
-        
-        if ($copy){
-            copy $file, $copy;
-            $file = $copy;
-        }
-       
         my @changed_lines;
         
         for my $sub (@$struct){
+
             my $start_line = $sub->start;
             my $end_line = $sub->end;
 
-            tie my @tie_file, 'Tie::File', $file, recsep => $ENV{DES_EOL}
-              or die $!;
-
             my $line_num = 0;
 
-            for my $line (@tie_file){
+            for my $line (@file_contents){
+
+                $line_num++;
+
+                if ($line_num < $start_line){
+                    next;
+                }
+                if ($line_num > $end_line){
+                    last;
+                }
+
+                if ($line =~ /$search/){
+                    my $orig = $line;
+                    $line =~ s/$search/$replace/g;
+                    push @changed_lines, [$orig, $line];
+                }
+            }
+        }
+
+        $p->{write_file_contents} = \@file_contents;
+
+        return \@changed_lines;
+    };                        
+}
+sub inject_after {
+    
+    trace() if $ENV{TRACE};
+
+    return sub {
+        
+        trace() if $ENV{TRACE};
+
+        my $p = shift;
+        my $struct = shift;
+
+        my $search = $p->{search};
+
+        if ($search && !$p->{regex}) {
+            $search = "\Q$search";
+        }
+
+        my $code = $p->{code};
+
+        if (!$search) {
+            croak "\nDevel::Examine::Subs::Engine::inject_after speaking:\n" .
+                "can't use inject_after engine without specifying a " .
+                "search term\n\n";
+        }
+        if (!$code) {
+            croak "\nDevel::Examine::Subs::Engine::inject_after speaking:\n" .
+                "can't use inject_after engine without code to inject\n\n";
+
+        }
+
+        my $file = $p->{file};
+        my @file_contents = @{$p->{file_contents}};
+
+        my @processed;
+
+        my $added_lines = 0;
+
+        my @subs;
+
+        for my $sub (@$struct) {
+            push @subs, $sub->name;
+        }
+
+        my $des = Devel::Examine::Subs->new(file => $p->{file});
+        my $subs_hash = $des->objects(objects_in_hash => 1, include => \@subs);
+
+        my @sorted_subs = sort {
+                $subs_hash->{$a}->start <=> $subs_hash->{$b}->start
+            } keys %$subs_hash;
+
+        for (@sorted_subs){
+
+            my $sub = $subs_hash->{$_};
+
+            my $num_injects = $p->{injects} // 1;
+
+            push @processed, $sub->name;
+
+            my $start_line = $sub->start;
+            my $end_line = $sub->end;
+
+            $start_line += $added_lines;
+            $end_line += $added_lines;
+
+            my $line_num = 0;
+            my $new_lines = 0; # don't search added lines
+
+            for my $line (@file_contents){
                 $line_num++;
                 if ($line_num < $start_line){
                     next;
@@ -315,138 +408,36 @@ sub search_replace {
                 if ($line_num > $end_line){
                     last;
                 }
-                
-                if ($line =~ /$search/){
-                    my $orig = $line;
-                    $line =~ s/$search/$replace/g;
-                    push @changed_lines, [$orig, $line];
-                }
-            }
-            untie @tie_file;
-        }
-        return \@changed_lines;
-    };                        
-}
-sub inject_after {
-    trace() if $ENV{TRACE};
 
-    return sub {
-        trace() if $ENV{TRACE};
+                if ($line =~ /$search/ && ! $new_lines){
 
-        my $p = shift;
-        my $struct = shift;
-    
-        my $search = $p->{search};
+                    my $location = $line_num;
 
-        if ($search && ! $p->{regex}){
-            $search = "\Q$search";
-        }
+                    my $indent = '';
 
-        my $num_injects = $p->{injects} // 1;
-        my $code = $p->{code};
-        my $copy = $p->{copy};
-        my $sub_def = $p->{sub_def};
-
-        if (! $sub_def && ! $search){
-            croak "\nDevel::Examine::Subs::Engine::inject_after speaking:\n" .
-                    "can't use inject_after engine without specifying a " .
-                    "search term\n\n";
-        }
-        if (! $code){
-            croak "\nDevel::Examine::Subs::Engine::inject_after speaking:\n" .
-                  "can't use inject_after engine without code to inject\n\n";
-
-        }
-        
-        my $file = $p->{file};
- 
-        copy $file, "$file.bak";
-
-        if ($copy){
-            if (-f $copy){
-                unlink $copy;
-            }
-            copy $file, $copy;
-            $file = $copy;
-        }
-
-        my @unprocessed;       
-        my @processed;
-        
-        for my $sub (@$struct){
-            push @unprocessed, $sub->name;
-        }
-
-        for my $uname (@unprocessed){
-        
-            my $des = Devel::Examine::Subs->new;
-
-            my $params = {
-                        file => $file,
-                        pre_filter => ['subs', 'objects'],
-                        pre_filter_return => 2,
-                        search => $search,
-            };
-
-            my $struct = $des->run($params); 
-
-            for my $sub (@$struct){
-
-                next unless $sub->name eq $uname;
-
-                push @processed, $sub->name;
-                
-                my $start_line = $sub->start;
-                my $end_line = $sub->end;
-            
-                tie my @tie_file, 'Tie::File', $file, recsep => $ENV{DES_EOL}
-                  or die $!;
-
-                my $line_num = 0;
-                my $new_lines = 0; # don't search added lines
-
-                for my $line (@tie_file){
-                    $line_num++;
-
-                    if ($line_num < $start_line){
-                        next;
+                    if (! $p->{no_indent}){
+                        if ($line =~ /^(\s+)/ && $1){
+                            $indent = $1;
+                        }
                     }
-                    if ($line_num > $end_line){
+                    for (@$code){
+                        splice @file_contents, $location++, 0, $indent . $_;
+                        $new_lines++;
+                        $added_lines++;
+                    }
+
+                    # stop injecting after N search finds
+
+                    $num_injects--;
+                    if ($num_injects == 0){
                         last;
                     }
 
-                    if ($line =~ /$search/ && ! $new_lines){
-                       
-                        my $location = $line_num;
-
-                        my $indent = '';
-
-                        if (! $p->{no_indent}){
-                            if ($line =~ /^(\s+)/ && $1){
-                                $indent = $1;
-                            }
-                        }
-                        for my $line (@$code){
-                            splice @tie_file, $location++, 0, $indent . $line; 
-                            $new_lines++;
-                            $end_line++;
-                        }
-
-                        # stop injecting after N search finds
-
-                        $num_injects--;
-                        
-                        if ($num_injects == 0){
-                            untie @tie_file;
-                            last;
-                        }
-                        
-                    }
-                    $new_lines-- if $new_lines != 0;
                 }
-                untie @tie_file;
+                $new_lines-- if $new_lines != 0;
             }
         }
+        $p->{write_file_contents} = \@file_contents;
         return \@processed;
     };                        
 }
