@@ -1,12 +1,11 @@
-package Devel::Examine::Subs::Prefilter;
+package Devel::Examine::Subs::Prefilter 1.39;
+use 5.012;
 use strict;
 use warnings;
 
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '1.37';
-
 BEGIN {
 
     # we need to do some trickery for DTS due to a circular install
@@ -22,6 +21,7 @@ BEGIN {
 };
 
 sub new {
+    
     trace() if $ENV{TRACE};
 
     my $self = {};
@@ -34,6 +34,7 @@ sub new {
     return $self;
 }
 sub _dt {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -51,6 +52,7 @@ sub _dt {
     return $dt;
 }
 sub exists {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -64,9 +66,11 @@ sub exists {
     }
 }
 sub subs {
+    
     trace() if $ENV{TRACE};
     
     return sub {
+        
         trace() if $ENV{TRACE};
 
         my $p = shift;
@@ -91,7 +95,7 @@ sub subs {
                 $s->{$f}{subs}{$sub}{start}++;
                 $s->{$f}{subs}{$sub}{end}++;
                 $s->{$f}{subs}{$sub}{name} = $sub;
-                @{ $s->{$f}{subs}{$sub}{file} } = @{ $s->{$f}{TIE_file} };
+                @{ $s->{$f}{subs}{$sub}{file} } = @{ $s->{$f}{contents} };
                 push @subs, $s->{$f}{subs}{$sub};
             }
         }
@@ -99,9 +103,11 @@ sub subs {
     };
 }
 sub file_lines_contain {
+    
     trace() if $ENV{TRACE};
 
     return sub {
+        
         trace() if $ENV{TRACE};
 
         my $p = shift;
@@ -123,7 +129,7 @@ sub file_lines_contain {
             for my $sub (keys %{$s->{$f}{subs}}){
                 my $found = 0;
                 my @has;
-                for (@{$s->{$f}{subs}{$sub}{TIE_file_sub}}){
+                for (@{$s->{$f}{subs}{$sub}{contents}}){
                     if ($_ and /$search/){
                         $found++;
                         push @has, $_;
@@ -133,16 +139,18 @@ sub file_lines_contain {
                     delete $s->{$f}{subs}{$sub};                
                     next;
                 }
-                $s->{$f}{subs}{$sub}{TIE_file_sub} = \@has;
+                $s->{$f}{subs}{$sub}{contents} = \@has;
             }
         }
         return $struct;
     };
 }
 sub end_of_last_sub {
+    
     trace() if $ENV{TRACE};
     
     return sub {
+        
         trace() if $ENV{TRACE};
         
         my $p = shift;
@@ -161,9 +169,11 @@ sub end_of_last_sub {
     };
 }
 sub _test {
+    
     trace() if $ENV{TRACE};
 
     return sub {
+        
         trace() if $ENV{TRACE};
         my $p = shift;
         my $struct = shift;
@@ -171,11 +181,13 @@ sub _test {
     };
 }
 sub objects {
+    
     trace() if $ENV{TRACE};
 
     # uses 'subs' pre_filter
 
     return sub {
+        
         trace() if $ENV{TRACE};
 
         my $p = shift;
