@@ -1,13 +1,11 @@
-package Devel::Examine::Subs::Preprocessor;
-
+package Devel::Examine::Subs::Preprocessor 1.39;
+use 5.012;
 use strict;
 use warnings;
 
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '1.37';
-
 BEGIN {
 
     # we need to do some trickery for DTS due to a circular install
@@ -23,6 +21,7 @@ BEGIN {
 };
 
 sub new {
+
     trace() if $ENV{TRACE};
 
     my $self = {};
@@ -36,6 +35,7 @@ sub new {
 }
 
 sub _dt {
+
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -51,7 +51,9 @@ sub _dt {
 }
 
 sub exists {
+
     trace() if $ENV{TRACE};
+
     my $self = shift;
     my $string = shift;
 
@@ -64,6 +66,7 @@ sub exists {
 }
 
 sub module {
+
     trace() if $ENV{TRACE};
 
     return sub {
@@ -97,40 +100,39 @@ sub module {
 }
 
 sub inject {
+
     trace() if $ENV{TRACE};
 
     return sub {
+
         trace() if $ENV{TRACE};
 
         my $p = shift;
-        my $file = $p->{file};
 
-        tie my @file, 'Tie::File', $file, recsep => $ENV{DES_EOL}
-          or die $!;
+        my @file_contents = @{ $p->{file_contents} };
 
         if ($p->{inject_use}) {
 
             my $use = qr/use\s+\w+/;
 
             my ($index) = grep {
-                $file[$_] =~ $use
-            } 0..$#file;
+                $file_contents[$_] =~ $use
+            } 0..$#file_contents;
 
             if (!$index) {
                 ($index) = grep {
-                    $file[$_] =~ /^package\s+\w+/
-                } 0..$#file;
+                    $file_contents[$_] =~ /^package\s+\w+/
+                } 0..$#file_contents;
             }
 
             if ($index) {
                 for (@{$p->{inject_use}}) {
-                    splice @file, $index, 0, $_;
+                    splice @file_contents, $index, 0, $_;
                 }
             }
 
-            untie @file;
+            $p->{write_file_contents} = \@file_contents;
 
-            return;
         }
 
         if ($p->{inject_after_sub_def}) {
@@ -149,7 +151,7 @@ sub inject {
 
             my $is_multi = 0;
 
-            while (my ($i, $e) = each @file){
+            while (my ($i, $e) = each @file_contents){
 
                 if ($e =~ /^\n/){
                     push @new_file, "\n";
@@ -160,8 +162,8 @@ sub inject {
                 my $count = $i;
                 $count++;
 
-                while ($count < @file){
-                    if ($file[$count] =~ /^(\s*)\S/){
+                while ($count < @file_contents){
+                    if ($file_contents[$count] =~ /^(\s*)\S/){
                         $indent = $1;
                         last;
                     }
@@ -178,7 +180,7 @@ sub inject {
                     }
                 }
                 elsif ($e =~ $multi_line) {
-                    if ($file[$count] =~ /\s*\{\s*(?!\s*[\S])/) {
+                    if ($file_contents[$count] =~ /\s*\{\s*(?!\s*[\S])/) {
                         $is_multi = 1;
                         next;
                     }
@@ -191,33 +193,30 @@ sub inject {
                     $is_multi = 0;
                 }
             }
-
-            @file = @new_file;
+            $p->{write_file_contents} = \@new_file;
         }
     }
 }
 
 sub remove {
+
     trace() if $ENV{TRACE};
 
     return sub {
+
         trace() if $ENV{TRACE};
         
         my $p = shift;
-        my $file = $p->{file};        
+        my @file = @{ $p->{file_contents}};
+
         my $delete = $p->{delete};
 
-        tie my @file, 'Tie::File', $file ,recsep => $ENV{DES_EOL} 
-          or die $!; 
-    
         for my $find (@$delete){
             while (my ($index) = grep { $file[$_] =~ $find } 0..$#file){
                 splice @file, $index, 1;
             }
         }
-        untie @file;
-
-        return;
+        $p->{write_file_contents} = \@file;
     }
 }
 
