@@ -1,11 +1,10 @@
-package Devel::Examine::Subs::Sub;
+package Devel::Examine::Subs::Sub 1.39;
+use 5.012;
 use strict;
 use warnings;
 
 use Data::Dumper;
 
-our $VERSION = '1.37';
-
 BEGIN {
 
     # we need to do some trickery for DTS due to a circular install
@@ -21,6 +20,7 @@ BEGIN {
 };
 
 sub new {
+    
     trace() if $ENV{TRACE};
 
     my $class = shift;
@@ -35,26 +35,35 @@ sub new {
     return $self;
 }
 sub name {
+    
     trace() if $ENV{TRACE};
+    
     my $self = shift;
     return $self->{data}{name};
 }
 sub start {
+    
     trace() if $ENV{TRACE};
+    
     my $self = shift;
     return $self->{data}{start};
 }
 sub end {
+    
     trace() if $ENV{TRACE};
+    
     my $self = shift;
     return $self->{data}{end};
 }
 sub line_count {
+    
     trace() if $ENV{TRACE};
+    
     my $self = shift;
     return $self->{data}{num_lines};
 }
 sub lines {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -74,11 +83,12 @@ sub lines {
     return \@line_linenum;
 }
 sub code {
+    
     trace() if $ENV{TRACE};
 
     my $self = shift;
 
-    my $code = $self->{data}{TIE_file_sub};
+    my $code = $self->{data}{contents};
 
     return $code;
 }
